//
// C++ Interface:
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
// License: GPL
//

#ifndef KMFDOCUMENTINFO_H
#define KMFDOCUMENTINFO_H

#include "kmyfirewalldocumentinfo.h"

// TQt includes

// KDE includes
#include <tdemacros.h>

// project includes
namespace KMF {
class KMFDoc;

class TDE_EXPORT KMFDocumentInfo : public KMyFirewallDocumentInfo {
	TQ_OBJECT
  

public:
	KMFDocumentInfo(TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
	~KMFDocumentInfo();
	/*$PUBLIC_FUNCTIONS$*/

	void loadDoc( KMFDoc* );
	
public slots:
	/*$PUBLIC_SLOTS$*/

protected:
	/*$PROTECTED_FUNCTIONS$*/

protected slots:
	/*$PROTECTED_SLOTS$*/
	virtual void accept();
	void slotSaveAsTemplate();
	void slotHelp();
	
private: // data
	KMFDoc *m_doc;

signals:
   void sigSaveAsTemplate();

};
}
#endif

